diff --git a/tools/droiddoc/templates-sdk/sdkpage.cs b/tools/droiddoc/templates-sdk/sdkpage.cs
index bbe6e976c..52aa58716 100644
--- a/tools/droiddoc/templates-sdk/sdkpage.cs
+++ b/tools/droiddoc/templates-sdk/sdkpage.cs
@@ -272,6 +272,115 @@
+
+
Android Studio Bundle
+
+
+ Platform |
+ Package |
+ Size |
+ SHA1 Sum |
+
+
+ Windows 32-bit |
+
+
+ |
+ bytes |
+ |
+
+
+ Windows 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+ Mac OS X 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+ Linux 32-bit |
+
+
+ |
+ bytes |
+ |
+
+
+ Linux 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+
+
+
+
+
SDK Tools Only
+
+
+ Platform |
+ Package |
+ Size |
+ MD5 Checksum |
+
+
+ Windows 32 & 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+
+
+ (Recommended)
+ |
+ bytes |
+ |
+
+
+ Mac OS X 32 & 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+ Linux 32 & 64-bit |
+
+
+ |
+ bytes |
+ |
+
+
+
+
ADT Bundle
-
SDK Tools Only
-
-
- Platform |
- Package |
- Size |
- MD5 Checksum |
-
-
- Windows 32 & 64-bit |
-
-
- |
- bytes |
- |
-
-
-
-
- (Recommended)
- |
- bytes |
- |
-
-
- Mac OS X 32 & 64-bit |
-
-
- |
- bytes |
- |
-
-
- Linux 32 & 64-bit |
-
-
- |
- bytes |
- |
-
-
+
+
+
+
@@ -414,9 +479,9 @@ var:sdk.linux_download
if (os) {
$('#not-supported').hide();
/* set up primary adt download button */
$('#download-bundle-button').show();
- $('#download-bundle-button').append("Download Eclipse ADT
with the Android SDK for " + os + "");
+ $('#download-bundle-button').append("Download Android Studio
with the Android SDK for " + os + "");
$('#download-bundle-button').click(function() {return onDownload(this,true,true);}).attr('href', bundlename);
/* set up sdk tools only button */
@@ -439,7 +504,7 @@ var:sdk.linux_download
/* if it's a bundle, show the 32/64-bit picker */
if (bundle) {
- $("#downloadForRealz").attr('bundle','true');
+ $("#downloadForRealz").attr('Eclipse ADT Bundle','true');
if ($("#downloadForRealz").text().indexOf("Mac") == -1) {
$("p#bitpicker").show();
} else {
@@ -414,9 +479,9 @@ var:sdk.linux_download
if (os) {
$('#not-supported').hide();
- /* set up primary adt download button */
+ /* set up primary Android Studio download button */
$('#download-bundle-button').show();